@@ -13,7 +13,6 @@ expanded/generalized to accommodate other types in the future.
 
 from __future__ import print_function
 
-from pxr import Ndr
 from pxr import Sdr
 from pxr.Sdf import ValueTypeNames as SdfTypes
 from pxr import Tf
@@ -63,14 +62,14 @@ def TestBasicProperties(node):
 
 
     properties = {
-        "inputA": node.GetInput("inputA"),
-        "inputB": node.GetInput("inputB"),
-        "inputC": node.GetInput("inputC"),
-        "inputD": node.GetInput("inputD"),
-        "inputF2": node.GetInput("inputF2"),
-        "inputStrArray": node.GetInput("inputStrArray"),
-        "resultF": node.GetOutput("resultF"),
-        "resultI": node.GetOutput("resultI"),
+        "inputA": node.GetShaderInput("inputA"),
+        "inputB": node.GetShaderInput("inputB"),
+        "inputC": node.GetShaderInput("inputC"),
+        "inputD": node.GetShaderInput("inputD"),
+        "inputF2": node.GetShaderInput("inputF2"),
+        "inputStrArray": node.GetShaderInput("inputStrArray"),
+        "resultF": node.GetShaderOutput("resultF"),
+        "resultI": node.GetShaderOutput("resultI"),
     }
 
     assert properties["inputA"].GetName() == "inputA"
@@ -204,7 +203,7 @@ def TestShadingProperties(node):
     for prop, expected in expected_mappings.items():
         indicator = properties[prop].GetTypeAsSdfType()
         assert indicator.GetSdfType() == expected[0]
-        assert indicator.GetNdrType() == expected[1]
+        assert indicator.GetSdrType() == expected[1]
 
     # --------------------------------------------------------------------------
     # Ensure asset identifiers are detected correctly
@@ -213,7 +212,7 @@ def TestShadingProperties(node):
     assert not properties["inputOptions"].IsAssetIdentifier()
     indicator = properties["inputAssetIdentifier"].GetTypeAsSdfType()
     assert indicator.GetSdfType() == SdfTypes.Asset
-    assert indicator.GetNdrType() == Sdr.PropertyTypes.String
+    assert indicator.GetSdrType() == Sdr.PropertyTypes.String
 
     # Nested pages and VStructs are only possible in args files
     if not isOSL:
@@ -280,10 +279,10 @@ def TestBasicNode(node, nodeSourceType, nodeDefinitionURI, nodeImplementationURI
     # --------------------------------------------------------------------------
 
     nodeInputs = {propertyName: node.GetShaderInput(propertyName)
-                  for propertyName in node.GetInputNames()}
+                  for propertyName in node.GetShaderInputNames()}
 
     nodeOutputs = {propertyName: node.GetShaderOutput(propertyName)
-                   for propertyName in node.GetOutputNames()}
+                   for propertyName in node.GetShaderOutputNames()}
 
     assert node.GetName() == nodeName
     assert node.GetContext() == nodeContext
@@ -312,16 +311,16 @@ def TestBasicNode(node, nodeSourceType, nodeDefinitionURI, nodeImplementationURI
     assert nodeOutputs["outputNormal"] is not None
     assert nodeOutputs["outputColor"] is not None
     assert nodeOutputs["outputVector"] is not None
-    print(set(node.GetInputNames()))
-    assert set(node.GetInputNames()) == {
+    print(set(node.GetShaderInputNames()))
+    assert set(node.GetShaderInputNames()) == {
         "inputA", "inputB", "inputC", "inputD", "inputF2", "inputF3", "inputF4",
         "inputF5", "inputInterp", "inputOptions", "inputPoint", "inputNormal",
         "inputStruct", "inputAssetIdentifier", "primvarNamingProperty",
         "invalidPrimvarNamingProperty", "inputStrArray"
     }
-    assert set(node.GetOutputNames()) == outputNames
+    assert set(node.GetShaderOutputNames()) == outputNames
 
-    # There may be additional metadata passed in via the NdrNodeDiscoveryResult.
+    # There may be additional metadata passed in via the SdrShaderNodeDiscoveryResult.
     # So, ensure that the bits we expect to see are there instead of doing 
     # an equality check.
     nodeMetadata = node.GetMetadata()
@@ -353,10 +352,10 @@ def TestShaderSpecificNode(node):
 
 
     shaderInputs = {propertyName: node.GetShaderInput(propertyName)
-                    for propertyName in node.GetInputNames()}
+                    for propertyName in node.GetShaderInputNames()}
 
     shaderOutputs = {propertyName: node.GetShaderOutput(propertyName)
-                     for propertyName in node.GetOutputNames()}
+                     for propertyName in node.GetShaderOutputNames()}
 
     assert len(shaderInputs) == 17
     assert len(shaderOutputs) == numOutputs
@@ -441,10 +440,10 @@ def TestShaderPropertiesNode(node):
         assert node.GetSourceType() == "glslfx"
 
     nodeInputs = {propertyName: node.GetShaderInput(propertyName)
-                  for propertyName in node.GetInputNames()}
+                  for propertyName in node.GetShaderInputNames()}
 
     nodeOutputs = {propertyName: node.GetShaderOutput(propertyName)
-                  for propertyName in node.GetOutputNames()}
+                  for propertyName in node.GetShaderOutputNames()}
 
     # For each property, we test that:
     # * The property has the expected SdrPropertyType
@@ -454,42 +453,42 @@ def TestShaderPropertiesNode(node):
     property = nodeInputs["inputInt"]
     assert property.GetType() == Sdr.PropertyTypes.Int
     assert GetType(property) == Tf.Type.FindByName("int")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputString"]
     assert property.GetType() == Sdr.PropertyTypes.String
     assert GetType(property) == Tf.Type.FindByName("string")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputFloat"]
     assert property.GetType() == Sdr.PropertyTypes.Float
     assert GetType(property) == Tf.Type.FindByName("float")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputColor"]
     assert property.GetType() == Sdr.PropertyTypes.Color
     assert GetType(property) == Tf.Type.FindByName("GfVec3f")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputPoint"]
     assert property.GetType() == Sdr.PropertyTypes.Point
     assert GetType(property) == Tf.Type.FindByName("GfVec3f")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputNormal"]
     assert property.GetType() == Sdr.PropertyTypes.Normal
     assert GetType(property) == Tf.Type.FindByName("GfVec3f")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputVector"]
     assert property.GetType() == Sdr.PropertyTypes.Vector
     assert GetType(property) == Tf.Type.FindByName("GfVec3f")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputMatrix"]
     assert property.GetType() == Sdr.PropertyTypes.Matrix
     assert GetType(property) == Tf.Type.FindByName("GfMatrix4d")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     if node.GetName() != "TestShaderPropertiesNodeUSD":
         # XXX Note that 'struct' and 'vstruct' types are currently unsupported
@@ -499,107 +498,107 @@ def TestShaderPropertiesNode(node):
         property = nodeInputs["inputStruct"]
         assert property.GetType() == Sdr.PropertyTypes.Struct
         assert GetType(property) == Tf.Type.FindByName("TfToken")
-        assert Ndr._ValidateProperty(node, property)
+        assert Sdr._ValidateProperty(node, property)
 
         property = nodeInputs["inputVstruct"]
         assert property.GetType() == Sdr.PropertyTypes.Vstruct
         assert GetType(property) == Tf.Type.FindByName("TfToken")
-        assert Ndr._ValidateProperty(node, property)
+        assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputIntArray"]
     assert property.GetType() == Sdr.PropertyTypes.Int
     assert GetType(property) == Tf.Type.FindByName("VtArray<int>")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputStringArray"]
     assert property.GetType() == Sdr.PropertyTypes.String
     assert GetType(property) == Tf.Type.FindByName("VtArray<string>")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputFloatArray"]
     assert property.GetType() == Sdr.PropertyTypes.Float
     assert GetType(property) == Tf.Type.FindByName("VtArray<float>")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputColorArray"]
     assert property.GetType() == Sdr.PropertyTypes.Color
     assert GetType(property) ==  Tf.Type.FindByName("VtArray<GfVec3f>")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputPointArray"]
     assert property.GetType() == Sdr.PropertyTypes.Point
     assert GetType(property) == Tf.Type.FindByName("VtArray<GfVec3f>")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputNormalArray"]
     assert property.GetType() == Sdr.PropertyTypes.Normal
     assert GetType(property) == Tf.Type.FindByName("VtArray<GfVec3f>")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputVectorArray"]
     assert property.GetType() == Sdr.PropertyTypes.Vector
     assert GetType(property) == Tf.Type.FindByName("VtArray<GfVec3f>")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputMatrixArray"]
     assert property.GetType() == Sdr.PropertyTypes.Matrix
     assert GetType(property) == Tf.Type.FindByName("VtArray<GfMatrix4d>")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputFloat2"]
     assert property.GetType() == Sdr.PropertyTypes.Float
     assert GetType(property) == Tf.Type.FindByName("GfVec2f")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputFloat3"]
     assert property.GetType() == Sdr.PropertyTypes.Float
     assert GetType(property) == Tf.Type.FindByName("GfVec3f")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputFloat4"]
     assert property.GetType() == Sdr.PropertyTypes.Float
     assert GetType(property) == Tf.Type.FindByName("GfVec4f")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputAsset"]
     assert property.GetType() == Sdr.PropertyTypes.String
     assert GetType(property) == Tf.Type.FindByName("SdfAssetPath")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputAssetArray"]
     assert property.GetType() == Sdr.PropertyTypes.String
     assert GetType(property) == Tf.Type.FindByName("VtArray<SdfAssetPath>")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputColorRoleNone"]
     assert property.GetType() == Sdr.PropertyTypes.Float
     assert GetType(property) == Tf.Type.FindByName("GfVec3f")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputPointRoleNone"]
     assert property.GetType() == Sdr.PropertyTypes.Float
     assert GetType(property) == Tf.Type.FindByName("GfVec3f")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputNormalRoleNone"]
     assert property.GetType() == Sdr.PropertyTypes.Float
     assert GetType(property) == Tf.Type.FindByName("GfVec3f")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeInputs["inputVectorRoleNone"]
     assert property.GetType() == Sdr.PropertyTypes.Float
     assert GetType(property) == Tf.Type.FindByName("GfVec3f")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     property = nodeOutputs["outputSurface"]
     assert property.GetType() == Sdr.PropertyTypes.Terminal
     assert GetType(property) == Tf.Type.FindByName("TfToken")
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     # Specific test of implementationName feature, we can skip type-tests
     property = nodeInputs["normal"]
     assert property.GetImplementationName() == "aliasedNormalInput"
-    assert Ndr._ValidateProperty(node, property)
+    assert Sdr._ValidateProperty(node, property)
 
     if node.GetName() != "TestShaderPropertiesNodeOSL" and \
         node.GetName() != "TestShaderPropertiesNodeARGS" :
@@ -608,17 +607,17 @@ def TestShaderPropertiesNode(node):
         property = nodeInputs["inputColor4"]
         assert property.GetType() == Sdr.PropertyTypes.Color4
         assert GetType(property) == Tf.Type.FindByName("GfVec4f")
-        assert Ndr._ValidateProperty(node, property)
+        assert Sdr._ValidateProperty(node, property)
 
         # oslc v1.11.14 does not allow arrays of structs as parameter.
         property = nodeInputs["inputColor4Array"]
         assert property.GetType() == Sdr.PropertyTypes.Color4
         assert GetType(property) ==  Tf.Type.FindByName("VtArray<GfVec4f>")
-        assert Ndr._ValidateProperty(node, property)
+        assert Sdr._ValidateProperty(node, property)
 
         property = nodeInputs["inputColor4RoleNone"]
         assert property.GetType() == Sdr.PropertyTypes.Float
         assert GetType(property) == Tf.Type.FindByName("GfVec4f")
-        assert Ndr._ValidateProperty(node, property)
+        assert Sdr._ValidateProperty(node, property)
 
 
